@@ -1,6 +1,5 @@
 import datetime
 import logging
-from npd_cat_corr.client import BloombergClient
 import pandas as pd
 import os
 import calendar
@@ -13,7 +12,7 @@ def run_summary_cat_report(output_dir, df):
 
     rev_corr_data = most_corr_by_ticker_yy(df, "SALES_REV_TURN", measure_est="BEST_SALES")
     profit_corr_data = most_corr_by_ticker_yy(df, "GROSS_PROFIT", measure_est=None)
-    eps_corr_data = most_corr_by_ticker_yy(df, "IS_COMP_EPS_ADJUSTED", measure_est="BEST_EPS")
+    eps_corr_data = most_corr_by_ticker_yy(df, "IS_COMP_EPS_EXCL_STOCK_COMP", measure_est="BEST_EPS")
 
     writer = pd.ExcelWriter(output_dir + "YYcorr.xlsx")
     rev_corr_data[["symbol","category","category_corr","total_dollars_corr","share_of_total_dollars","estimate_corr"]].to_excel(writer, sheet_name="Rev YY", index=False)
@@ -95,11 +94,11 @@ def run_cat_report(output_dir, ticker, df):
         raise Exception("Not enough data for ticker")
 
     writer = pd.ExcelWriter( output_dir + ticker + "_category_correlation.xlsx")
-    try:
-        ticker_excel(writer, df, ticker)
-    except:
-        writer.close()
-        os.remove(output_dir + ticker + "_category_correlation.xlsx")
+    #try:
+    ticker_excel(writer, df, ticker)
+    #except:
+    writer.close()
+        #os.remove(output_dir + ticker + "_category_correlation.xlsx")
         
 
 
@@ -116,7 +115,7 @@ def get_k_best(df, k, measure):
 def ticker_excel(writer, df, ticker):
 
     sdf = df[df["symbol"] == ticker]
-    sdf = sdf.drop(columns=["IS_EPS","IS_ADJUSTED_EPS_AS_REPORTED","ARD_ADJUSTED_EPS","ARD_GROSS_PROFITS","IS_BASIC_EPS_CONT_OPS"])
+    sdf = sdf.drop(columns=["IS_EPS","IS_ADJUSTED_EPS_AS_REPORTED","ARD_ADJUSTED_EPS","ARD_GROSS_PROFITS","IS_BASIC_EPS_CONT_OPS","IS_COMP_EPS_ADJUSTED"])
     sdf = sdf.dropna(axis=1, how="all")
     for x in sdf.columns:
         if x not in NON_SALES_COLS:
@@ -130,7 +129,7 @@ def ticker_excel(writer, df, ticker):
 
     sdf_yy = sdf.copy()
     for x in sdf_yy.columns:
-        if x not in NON_SALES_COLS or x in ["total_dollars","SALES_REV_TURN","BEST_SALES","GROSS_PROFIT","IS_COMP_EPS_ADJUSTED","BEST_EPS"]:
+        if x not in NON_SALES_COLS or x in ["total_dollars","SALES_REV_TURN","BEST_SALES","GROSS_PROFIT","IS_COMP_EPS_EXCL_STOCK_COMP","BEST_EPS"]:
             sdf_yy[x] = sdf_yy[x].pct_change(periods=4)
     sdf_yy = sdf_yy.iloc[4:,:]
     
@@ -163,14 +162,14 @@ def ticker_excel(writer, df, ticker):
     yy_profit_cat_corr = yy_corr_df.loc[yy_best_profit_cat, "GROSS_PROFIT"]
     yy_profit_total_corr = yy_corr_df.loc["total_dollars", "GROSS_PROFIT"]
     yy_profit_cat_share = sdf[yy_best_profit_cat].sum() / sdf["total_dollars"].sum()
-    yy_best_eps_cat = get_k_best(sdf_yy[valid_categories + ["IS_COMP_EPS_ADJUSTED"]], 1, "IS_COMP_EPS_ADJUSTED")[0]
-    yy_eps_cat_corr = yy_corr_df.loc[yy_best_eps_cat, "IS_COMP_EPS_ADJUSTED"]
-    yy_eps_total_corr = yy_corr_df.loc["total_dollars", "IS_COMP_EPS_ADJUSTED"]
-    yy_eps_estimate_corr = yy_corr_df.loc["BEST_EPS","IS_COMP_EPS_ADJUSTED"]
+    yy_best_eps_cat = get_k_best(sdf_yy[valid_categories + ["IS_COMP_EPS_EXCL_STOCK_COMP"]], 1, "IS_COMP_EPS_EXCL_STOCK_COMP")[0]
+    yy_eps_cat_corr = yy_corr_df.loc[yy_best_eps_cat, "IS_COMP_EPS_EXCL_STOCK_COMP"]
+    yy_eps_total_corr = yy_corr_df.loc["total_dollars", "IS_COMP_EPS_EXCL_STOCK_COMP"]
+    yy_eps_estimate_corr = yy_corr_df.loc["BEST_EPS","IS_COMP_EPS_EXCL_STOCK_COMP"]
     yy_eps_cat_share = sdf[yy_best_eps_cat].sum() / sdf["total_dollars"].sum()
 
     yy_cols = list(sdf_yy.columns)
-    for col in [yy_cols.index(x) for x in [y for y in sdf_yy.columns if y not in NON_SALES_COLS] + ["SALES_REV_TURN","IS_COMP_EPS_ADJUSTED","GROSS_PROFIT","BEST_SALES","BEST_EPS",yy_best_rev_cat, yy_best_profit_cat, yy_best_eps_cat, "total_dollars"]]:
+    for col in [yy_cols.index(x) for x in [y for y in sdf_yy.columns if y not in NON_SALES_COLS] + ["SALES_REV_TURN","IS_COMP_EPS_EXCL_STOCK_COMP","GROSS_PROFIT","BEST_SALES","BEST_EPS",yy_best_rev_cat, yy_best_profit_cat, yy_best_eps_cat, "total_dollars"]]:
         yy_sheet.set_column(col, col, cell_format=percent_format)
 
     #ticker and category table
@@ -227,9 +226,9 @@ def ticker_excel(writer, df, ticker):
     yy_rev_consenesus_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "BEST_SALES", "SALES_REV_TURN", "Reported Revenue", yy_x_axis, len(sdf_yy))
     yy_profit_cat_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), yy_best_profit_cat, "GROSS_PROFIT", "Reported Profit", yy_x_axis, len(sdf_yy))
     yy_profit_total_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "total_dollars", "GROSS_PROFIT", "Reported Profit", yy_x_axis, len(sdf_yy))
-    yy_eps_cat_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), yy_best_eps_cat, "IS_COMP_EPS_ADJUSTED", "Reported EPS", yy_x_axis, len(sdf_yy))
-    yy_eps_total_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "total_dollars", "IS_COMP_EPS_ADJUSTED", "Reported EPS", yy_x_axis, len(sdf_yy))
-    yy_eps_consenesus_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "BEST_EPS", "IS_COMP_EPS_ADJUSTED", "Reported EPS", yy_x_axis, len(sdf_yy))
+    yy_eps_cat_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), yy_best_eps_cat, "IS_COMP_EPS_EXCL_STOCK_COMP", "Reported EPS", yy_x_axis, len(sdf_yy))
+    yy_eps_total_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "total_dollars", "IS_COMP_EPS_EXCL_STOCK_COMP", "Reported EPS", yy_x_axis, len(sdf_yy))
+    yy_eps_consenesus_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "BEST_EPS", "IS_COMP_EPS_EXCL_STOCK_COMP", "Reported EPS", yy_x_axis, len(sdf_yy))
 
     yy_visuals_sheet.insert_chart("A6", yy_rev_cat_chart)
     yy_visuals_sheet.insert_chart("E6", yy_rev_total_chart)
@@ -252,10 +251,10 @@ def ticker_excel(writer, df, ticker):
     raw_best_profit_cat = get_k_best(sdf, 1, "GROSS_PROFIT")[0]
     raw_profit_cat_corr = raw_corr_df.loc[raw_best_profit_cat, "GROSS_PROFIT"]
     raw_profit_total_corr = raw_corr_df.loc["total_dollars", "GROSS_PROFIT"]
-    raw_best_eps_cat = get_k_best(sdf, 1, "IS_COMP_EPS_ADJUSTED")[0]
-    raw_eps_cat_corr = raw_corr_df.loc[raw_best_eps_cat, "IS_COMP_EPS_ADJUSTED"]
-    raw_eps_total_corr = raw_corr_df.loc["total_dollars", "IS_COMP_EPS_ADJUSTED"]
-    raw_eps_estimate_corr = raw_corr_df.loc["BEST_EPS","IS_COMP_EPS_ADJUSTED"]
+    raw_best_eps_cat = get_k_best(sdf, 1, "IS_COMP_EPS_EXCL_STOCK_COMP")[0]
+    raw_eps_cat_corr = raw_corr_df.loc[raw_best_eps_cat, "IS_COMP_EPS_EXCL_STOCK_COMP"]
+    raw_eps_total_corr = raw_corr_df.loc["total_dollars", "IS_COMP_EPS_EXCL_STOCK_COMP"]
+    raw_eps_estimate_corr = raw_corr_df.loc["BEST_EPS","IS_COMP_EPS_EXCL_STOCK_COMP"]
 
     raw_cols = list(sdf.columns)
 
@@ -295,8 +294,8 @@ def ticker_excel(writer, df, ticker):
     raw_rev_total_chart = create_chart(workbook, "Raw Data", list(sdf.columns), "total_dollars", "SALES_REV_TURN", "Reported Revenue", raw_x_axis, len(sdf))
     raw_profit_cat_chart = create_chart(workbook, "Raw Data", list(sdf.columns), raw_best_profit_cat, "GROSS_PROFIT", "Reported Profit", raw_x_axis, len(sdf))
     raw_profit_total_chart = create_chart(workbook, "Raw Data", list(sdf.columns), "total_dollars", "GROSS_PROFIT", "Reported Profit", raw_x_axis, len(sdf))
-    raw_eps_cat_chart = create_chart(workbook, "Raw Data", list(sdf.columns), raw_best_eps_cat, "IS_COMP_EPS_ADJUSTED", "Reported EPS", raw_x_axis, len(sdf))
-    raw_eps_total_chart = create_chart(workbook, "Raw Data", list(sdf.columns), "total_dollars", "IS_COMP_EPS_ADJUSTED", "Reported EPS", raw_x_axis, len(sdf))
+    raw_eps_cat_chart = create_chart(workbook, "Raw Data", list(sdf.columns), raw_best_eps_cat, "IS_COMP_EPS_EXCL_STOCK_COMP", "Reported EPS", raw_x_axis, len(sdf))
+    raw_eps_total_chart = create_chart(workbook, "Raw Data", list(sdf.columns), "total_dollars", "IS_COMP_EPS_EXCL_STOCK_COMP", "Reported EPS", raw_x_axis, len(sdf))
     
     raw_visuals_sheet.insert_chart("A6", raw_rev_cat_chart)
     raw_visuals_sheet.insert_chart("E6", raw_rev_total_chart)
